@@ -7,15 +7,18 @@
 __author__ = "Miguel Martin"
 __version__ = "1"
 
+import logging
+from datetime import datetime, timedelta
 from pyquanttrade import market
 from pyquanttrade.market import marketData
 from pyquanttrade.engine.trade import TradeList
 from pyquanttrade.engine.test_result import TestResult
 import pandas as pd
 import numpy as np
-from datetime import datetime, timedelta
+from tqdm.auto import tqdm
 import plotly.graph_objects as go
-import logging
+from plotly.subplots import make_subplots
+
 
 # TODO: end positions closes to compute final return
 def backtest(
@@ -27,7 +30,8 @@ def backtest(
     commission=0,
     slippage_perc=0,
     level=logging.WARNING,
-    time_buffer=250
+    time_buffer=250,
+    progress_bar = False
 ):
     logging.basicConfig(level=level)
     if not isinstance(tickers, list):
@@ -127,7 +131,12 @@ def backtest(
                 remaining += money
         return remaining
 
-    for i, row in data_sims[tickers[0]].iterrows():
+    if progress_bar == True:
+        iterable = tqdm(data_sims[tickers[0]].iterrows(), total = data_sims[tickers[0]].shape[0], smoothing=0)
+    else:
+        iterable = data_sims[tickers[0]].iterrows()
+
+    for i, row in iterable:
         for ticker in policies.keys():
             if i in data_sims[ticker].index:
                 ticker_row = data_sims[ticker].loc[i]
@@ -149,10 +158,8 @@ def backtest(
     #Data returns only works with one ticker, for visualization purposes
     return result, data
 
-def plot_activity_list(activity_list):
+def plot_activity_list(activity_list, fig):
     
-    fig = go.Figure()
-
     #Decoding signal list as separate lists
     activity_list['buy_long'] = None
     activity_list.loc[activity_list['signals']=='Buy_long','buy_long'] = activity_list.loc[activity_list['signals']=='Buy_long','close']
@@ -194,6 +201,7 @@ def backtest_and_visualise(
     slippage_perc=0,
     level=logging.WARNING,
     time_buffer=250,
+    progress_bar = False
 ):
     assert ticker is not list
 
@@ -202,11 +210,12 @@ def backtest_and_visualise(
         ticker,
         start_at,
         stop_at,
-        capital=10000,
-        commission=0,
-        slippage_perc=0,
-        level=logging.WARNING,
-        time_buffer=250)
+        capital=capital,
+        commission=commission,
+        slippage_perc=slippage_perc,
+        level=level,
+        time_buffer=time_buffer,
+        progress_bar = progress_bar)
 
     for _, trade in result.data.trade_list.trades_closed.items():
         if trade.type == 'long':
@@ -216,10 +225,20 @@ def backtest_and_visualise(
             data.loc[trade.open_day,'signals'] = 'Sell_short'
             data.loc[trade.close_day,'signals'] = 'Close_short'
 
-    fig = plot_activity_list(data)
+    
 
+    if len(policy.second_plot_functions) > 0 :
+        fig = make_subplots(rows = 2, cols = 1, shared_xaxes=True)
+        for elem in policy.second_plot_functions:
+            if elem in data.columns:
+                fig.add_trace(go.Scatter(x = data.index, y = data[elem], mode='lines', name=elem, line={'width':1}), row = 2, col = 1)
+        
+    else: 
+        fig = go.Figure()
+
+    plot_activity_list(data, fig)
     for elem in policy.plot_functions:
         if elem in data.columns:
-            fig.add_trace(go.Scatter(x = data.index, y = data[elem], mode='lines', name=elem, line={'width':1}))
+            fig.add_trace(go.Scatter(x = data.index, y = data[elem], mode='lines', name=elem, line={'width':1}), row = 1, col = 1)
 
     return result, fig
\ No newline at end of file
